ttq

Macro ttq 

macro_rules! ttq {
    ($e:expr, $val:expr) => { ... };
    ($e:expr, $($arg:tt)*) => { ... };
}
ttq! is to used to expand the inner tiles, persist the result to tls (thread local storage) using a variable name and return a trimmed tile

use rtile::prelude::*;

tp!(numbers, "1, 2, 3, 4, 5");
let persisted_tile_name = "numbers";
ttq!(persisted_tile_name, "Numbers: @{numbers}");
assert_eq!(t!("@{numbers}").to_string(), "Numbers: 1, 2, 3, 4, 5".to_string());