macro_rules! kk {
($e:expr) => { ... };
($($arg:tt)*) => { ... };
}Expand description
kk! is to used to expand the inner tiles, by keeping the white spaces (i.e. do not trim any white spaces around the block) and return a tile
use rtile::prelude::*;
kp!(numbers, " 1, 2, 3, 4, 5 ");
let mut result = kk!(" Numbers: @{numbers} ");
kp!(numbers, " one, two, three, four, five ");
result |= k!(" In words: @{numbers} ");
assert_eq!(result.to_string(), ks!(" Numbers: 1, 2, 3, 4, 5 \n In words: one, two, three, four, five "));